package com.ruoyi.base.service;

import java.util.List;
import com.ruoyi.base.domain.RobotOpsVisitorRecord;

/**
 * 访客登记记录Service接口
 *
 * @author ruoyi
 * @date 2026-04-30
 */
public interface IRobotOpsVisitorRecordService
{
    /**
     * 查询访客登记记录
     *
     * @param id 访客登记记录主键
     * @return 访客登记记录
     */
    public RobotOpsVisitorRecord selectRobotOpsVisitorRecordById(Long id);

    /**
     * 查询访客登记记录列表
     *
     * @param robotOpsVisitorRecord 访客登记记录
     * @return 访客登记记录集合
     */
    public List<RobotOpsVisitorRecord> selectRobotOpsVisitorRecordList(RobotOpsVisitorRecord robotOpsVisitorRecord);

    /**
     * 新增访客登记记录
     *
     * @param robotOpsVisitorRecord 访客登记记录
     * @return 结果
     */
    public int insertRobotOpsVisitorRecord(RobotOpsVisitorRecord robotOpsVisitorRecord);

    /**
     * 修改访客登记记录
     *
     * @param robotOpsVisitorRecord 访客登记记录
     * @return 结果
     */
    public int updateRobotOpsVisitorRecord(RobotOpsVisitorRecord robotOpsVisitorRecord);

    /**
     * 批量删除访客登记记录
     *
     * @param ids 需要删除的访客登记记录主键集合
     * @return 结果
     */
    public int deleteRobotOpsVisitorRecordByIds(Long[] ids);

    /**
     * 删除访客登记记录信息
     *
     * @param id 访客登记记录主键
     * @return 结果
     */
    public int deleteRobotOpsVisitorRecordById(Long id);
}
